#### Measuring Rural and Urban Consciousness in Europe
#### Electoral Studies
#### Analysis Code


#### Set up----


# libraries
library(car)
library(psych)
library(viridis)
library(lavaan)
library(semTools)
library(paran)
library(semTable)
library(doParallel)
library(foreach)
library(dplyr)
library(questionr)

# options
plot_col_2 = viridis(2, begin=0.4, end=0.8)
plot_col_2_t = viridis(2, alpha=0.4, begin=0.4, end=0.8)

# folders
WD = rstudioapi::getActiveDocumentContext()$path 
setwd(dirname(WD))
print( getwd() )

# set up parallel processing
getDoParWorkers()
getDoParName()
registerDoParallel(makeCluster(10, type="PSOCK"))
getDoParWorkers()

# initialise parallel processing
cl = makeCluster(detectCores())
registerDoParallel(cl)

# data
rude = read.csv("RUDE_combined_ES.csv") 



#### Create rural v urban filter----


rude = rude[rude$ingroup %in% 1:2, ] # drop middle category ingroups
rude$rural = ifelse(rude$core_filt %in% 4:6, 1, 0)
rude$peri_fra = ifelse(rude$country == "fra" & rude$fra_filt == 3, 1, 0)
rude$sub_che = ifelse(rude$country == "che" & rude$core_dem_4 == 3, 1, 0)



#### Code demographics----


# gender
rude$female = ifelse(rude$core_dem_2 == 2, 1, 0)
rude$gender_oth = ifelse(rude$core_dem_2 == 3, 1, 0)

# education - degree (bach, masters, phd) or not
rude$educ_bach = ifelse(rude$gbr_core_dem_3 %in% 15:17, 1, 
                        ifelse(rude$fra_dem_3 %in% 7:9, 1, 
                               ifelse(rude$che_dem_3 %in% 7:9, 1, 
                                      ifelse(rude$deu_dem_3 %in% 7:9, 1, 
                                             ifelse(rude$esp_dem_3 %in% 7:9, 1, 0)))))
table(rude$educ_bach, rude$country, useNA="ifany")[2, ] / table(rude$country, useNA="ifany")

# employment - unemployed, employed, not in labour force
rude$unempl = ifelse(rude$core_dem_9==3, 1, 0)
rude$employ = ifelse(rude$core_dem_9==1, 1, 0)

# income - tertiles
rude$deu_dem_12 = Recode(rude$deu_dem_12, "11=NA")
rude$che_dem_12 = Recode(rude$che_dem_12, "11=NA")
rude$esp_dem_12 = Recode(rude$esp_dem_12, "11=NA")
rude$fra_dem_12 = Recode(rude$fra_dem_12, "11=NA")
rude$gbr_dem_12 = Recode(rude$gbr_dem_12, "16=NA; 17=NA")

rude$income_3t = 
  ifelse(rude$country=="deu", gtools::quantcut(rude$deu_dem_12, q=3, na.rm=TRUE), 
         ifelse(rude$country=="che", gtools::quantcut(rude$che_dem_12, q=3, na.rm=TRUE), 
                ifelse(rude$country=="esp", gtools::quantcut(rude$esp_dem_12, q=3, na.rm=TRUE), 
                       ifelse(rude$country=="fra", gtools::quantcut(rude$fra_dem_12, q=3, na.rm=TRUE), 
                              ifelse(rude$country=="gbr", gtools::quantcut(rude$gbr_dem_12, q=3, na.rm=TRUE), 
                                     NA)))))
table(rude$income_3t, rude$country, useNA="ifany")
rude$income_lo = car::recode(rude$income_3t, "1=1; else=0")
rude$income_med = car::recode(rude$income_3t, "2=1; else=0")
rude$income_hi = car::recode(rude$income_3t, "3=1; else=0")
rude$income_na = as.numeric(is.na(rude$income_3t))

# religion - 5 cat
rude$core_dem_10 = Recode(rude$core_dem_10, "11=NA; 12=NA")
rude$relNone = ifelse(rude$core_dem_10 == 10, 1, 0)
rude$relCath = ifelse(rude$core_dem_10 == 1, 1, 0)
rude$relProt = ifelse(rude$core_dem_10 %in% c(2, 3), 1, 0)
rude$relOthChr = ifelse(rude$core_dem_10 %in% c(4, 5), 1, 0)
rude$relOther = ifelse(rude$core_dem_10 %in% 6:9, 1, 0)

# age - 4 cat
rude$age1834 = ifelse(rude$core_dem_1 < 35, 1, 0)
rude$age3549 = ifelse(rude$core_dem_1 %in% 35:49, 1, 0)
rude$age5064 = ifelse(rude$core_dem_1 %in% 50:64, 1, 0)
rude$age65 = ifelse(rude$core_dem_1 > 64, 1, 0)
rude$age4cat = ifelse(rude$age1834 == 1, 1,
                      ifelse(rude$age3549 == 1, 2,
                             ifelse(rude$age5064 == 1, 3,
                                    ifelse(rude$age65 == 1, 4, NA))))

# ownhome
rude$ownhome = Recode(rude$core_dem_5, "0=0; 1=1; else=NA")

# citizen
rude$noncitizen = Recode(rude$core_dem_6, "1=0; 2=1; else=NA")

# left - right
rude$leftright = Recode(rude$core_pos_9, "11=NA")
rude$leftright = (rude$leftright / 5) - 1

# interest
rude$polinter = Recode(rude$core_int_1, "1=4; 2=3; 3=2; 4=1; 5=NA")

# turnout
rude$turnout = ifelse(rude$core_vot_1 %in% 1:3, 1, 0)

# regions
rude$region = ifelse(rude$country == "che", rude$che_sprachregion + 100,
                     ifelse(rude$country == "deu", rude$deu_east + 201,
                            ifelse(rude$country == "esp", rude$esp_dem_ccaa + 300,
                                   ifelse(rude$country == "fra", rude$fra_regions + 400,
                                          ifelse(rude$country == "gbr", rude$gbr_region + 500, NA)))))
table(rude$region, rude$country)
rude$region = as.factor(rude$region)
region_dummies = model.matrix(~ region - 1, data = rude)
rude = cbind(rude, region_dummies)

# weights
rude$che_weight = rude$che_weight / mean(rude$che_weight, na.rm=TRUE)
rude$wt_all = ifelse(rude$country=="che", rude$che_weight, 
                     ifelse(rude$country=="deu", rude$deu_weight, 
                            ifelse(rude$country=="fra", rude$fra_weight, 
                                   ifelse(rude$country=="gbr", rude$gbr_weight, 1))))
by(rude$wt_all, rude$country, summary)
rude$wt_all = ifelse(is.na(rude$wt_all), 0, rude$wt_all)


## Tables of demographics

# Table: Education (degree = 1)
# Unweighted
prop.table(table(rude$educ_bach, rude$country, exclude = FALSE), margin = 2)
# Weighted
prop.table(wtd.table(rude$educ_bach, rude$country, weights = rude$wt_all, 
                     normwt = TRUE), margin = 2)

# Table: Gender (female = 1)
# Unweighted
prop.table(table(rude$gender, rude$country, useNA = "no"), margin = 2)
# Weighted
prop.table(wtd.table(rude$gender, rude$country, weights = rude$wt_all, 
                     normwt = TRUE, useNA = "no"), margin = 2)

# Table: Age categories
# Unweighted
prop.table(table(rude$age4cat, rude$country, useNA = "no"), margin = 2)
# Weighted
prop.table(wtd.table(rude$age4cat, rude$country, weights = rude$wt_all, 
                     normwt = TRUE, useNA = "ifany"), margin = 2)

# Table: Region
# Unweighted
prop.table(table(rude$region, rude$country, useNA = "no"), margin = 2)
# Weighted
prop.table(wtd.table(rude$region, rude$country, weights = rude$wt_all, 
                     normwt = TRUE, useNA = "ifany"), margin = 2)

# Table: urban-rural
# Unweighted
prop.table(table(rude$rural, rude$country, useNA = "no"), margin = 2)
# Weighted
prop.table(wtd.table(rude$rural, rude$country, weights = rude$wt_all, 
                     normwt = TRUE, useNA = "ifany"))



#### Recode consciousness: core_consc_1 to core_consc_16----


cons = subset(rude, select=core_consc_1:core_consc_16)
cons_r = data.frame(sapply(cons, Recode, "1=5; 2=4; 3=3; 4=2; 5=1; 6=NA; else=NA"))
cons_o = data.frame(sapply(cons_r, ordered))
rude[, names(cons)] = data.frame(sapply(rude[, names(cons)], Recode, "1=5; 2=4; 3=3; 4=2; 5=1; 6=NA; else=NA"))

# sample sizes categorised as rural or urban and asked about urban or rural
table(rude$country, useNA="ifany")

# missing values - 19-29% missing listwise
by(cons_r, rude$country, function(x) colSums(is.na(x)))
cons_add = rowMeans(cons_r)
by(cons_add, rude$country, function(x) sum(is.na(x))) / by(cons_add, rude$country, length) 

# correlation matrices
cor(cons_r, use="pair")
pcor_cons = polychoric(cons_r)$rho




#### Subjective place identity vs DEGURBA----


table(rude$country, rude$degurba1)
table(rude$rural, rude$degurba1, rude$country)

create_weighted_table = function(country_code) {
  country_data = rude %>% filter(country == country_code)
  wtd_tbl = wtd.table(country_data$rural, country_data$degurba1, weights = country_data$wt_all)
  wtd_tbl_perc = prop.table(wtd_tbl) * 100
  return(wtd_tbl_perc)
}

cnts = c("che", "deu", "esp", "fra", "gbr")

placeid_degurb_tab = list()

for (c in cnts) {
  placeid_degurb_tab[[c]] = create_weighted_table(c)
}

for (c in cnts) {
  cat("\nTable for", c, ":\n")
  print(placeid_degurb_tab[[c]])
}




#### Reliability of additive scales----

# five national samples

alpha_tab = matrix(NA, ncol=5, nrow=6)

alpha_out = by(cons_r[, 1:5], rude$country, function(x) psych::alpha(x))
alpha_tab[1, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

alpha_out = by(cons_r[, 6:11], rude$country, function(x) psych::alpha(x))
alpha_tab[2, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

alpha_out = by(cons_r[, 12:13], rude$country, function(x) psych::alpha(x))
alpha_tab[3, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

alpha_out = by(cons_r[, 14:16], rude$country, function(x) psych::alpha(x))
alpha_tab[4, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

alpha_out = by(cons_r[, 6:16], rude$country, function(x) psych::alpha(x))
alpha_tab[5, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

alpha_out = by(cons_r, rude$country, function(x) psych::alpha(x))
alpha_tab[6, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

row.names(alpha_tab) = c("Identity (5-item)", "Representational resentment (6-item)", 
                         "Redistributional resentment (2-item)", "Cultural resentment (3-item)",
                         "General resentment (11-item)", "Place-based consciousness (16-item)")
colnames(alpha_tab) = names_cnt_ru = c("CHE", "DEU", "ESP", "FRA", "GBR")
round(alpha_tab, 2)

# save table
write.csv(alpha_tab, "alpha_consc_scales.csv", row.names=TRUE)

# split by rural urban

alpha_tab = matrix(NA, ncol=10, nrow=6)

alpha_out = by(cons_r[, 1:5], list(rude$country, rude$rural), function(x) psych::alpha(x))
alpha_tab[1, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

alpha_out = by(cons_r[, 6:11], list(rude$country, rude$rural), function(x) psych::alpha(x))
alpha_tab[2, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

alpha_out = by(cons_r[, 12:13], list(rude$country, rude$rural), function(x) psych::alpha(x))
alpha_tab[3, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

alpha_out = by(cons_r[, 14:16], list(rude$country, rude$rural), function(x) psych::alpha(x))
alpha_tab[4, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

alpha_out = by(cons_r[, 6:16], list(rude$country, rude$rural), function(x) psych::alpha(x))
alpha_tab[5, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

alpha_out = by(cons_r, list(rude$country, rude$rural), function(x) psych::alpha(x))
alpha_tab[6, ] = unlist(lapply(alpha_out, function(x) x[[1]][1]))

row.names(alpha_tab) = c("Identity (5-item)", "Representational resentment (6-item)", 
                         "Redistributional resentment (2-item)", "Cultural resentment (3-item)",
                         "General resentment (11-item)", "Place-based consciousness (16-item)")
colnames(alpha_tab) = names_cnt_ru = c("CHE-urb", "DEU-urb", "ESP-urb", "FRA-urb", "GBR-urb", 
                                       "CHE-rur", "DEU-rur", "ESP-rur", "FRA-rur", "GBR-rur")
round(alpha_tab, 2)

write.csv(alpha_tab, "alpha_consc_ru_scales.csv", row.names=TRUE)



#### CFAs by country----


mod_1fac = '
  consc =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5 + core_consc_6 + core_consc_7 
           + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
           + core_consc_12 + core_consc_13 + core_consc_14 + core_consc_15 + core_consc_16
'
mod_2fac = '
  iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
  resen =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
           + core_consc_12 + core_consc_13 + core_consc_14 + core_consc_15 + core_consc_16
'
mod_4fac = '
  iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
  rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
  redist =~ core_consc_12 + core_consc_13 
  cult =~ core_consc_14 + core_consc_15 + core_consc_16
'

mod_2hier_fac = '
  iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
  rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
  redist =~ core_consc_12 + core_consc_13 
  cult =~ core_consc_14 + core_consc_15 + core_consc_16
  resent =~ rep + redist + cult
'

mod_1f = list()
mod_2f = list()
mod_4f = list()
mod_2hf = list()
cfa_comp = list()
cnts = sort(unique(rude$country))


cfa_cnt = foreach(i = 1:5, .packages = c("lavaan", "semTools")) %dopar% {
  mod_1f[[i]] = lavaan::cfa(mod_1fac, data = rude[rude$country==cnts[i],], estimator = "MLR", 
                            missing = "ML", sampling.weights = "wt_all")
  mod_2f[[i]] = lavaan::cfa(mod_2fac, data = rude[rude$country==cnts[i],], estimator = "MLR", 
                            missing = "ML", sampling.weights = "wt_all")
  mod_4f[[i]] = lavaan::cfa(mod_4fac, data = rude[rude$country==cnts[i],], estimator = "MLR", 
                            missing = "ML", sampling.weights = "wt_all")
  mod_2hf[[i]] = lavaan::cfa(mod_2hier_fac, data = rude[rude$country==cnts[i],], estimator = "MLR", 
                             missing = "ML", sampling.weights = "wt_all")
  cfa_comp[[i]] = semTools::compareFit(mod_4f[[i]], mod_2hf[[i]], mod_2f[[i]], mod_1f[[i]]) 
  capture.output(summary(cfa_comp[[i]]), file = paste0("cfa_comparison_", cnts[i], ".txt"))
}



#### Measurement invariance CFAs by country----


# by country

mod_4fac = '
  iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
  rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
  redist =~ core_consc_12 + core_consc_13 
  cult =~ core_consc_14 + core_consc_15 + core_consc_16
'

cnts = sort(unique(rude$country))

fit_configural = lavaan::cfa(mod_4fac, data = rude, estimator = "MLR", 
                             missing = "ML", sampling.weights = "wt_all", 
                             group = "country")
fit_weak = lavaan::cfa(mod_4fac, data = rude, estimator = "MLR", missing = "ML", 
                            sampling.weights = "wt_all", group = "country", 
                            group.equal = "loadings")
fit_strong = lavaan::cfa(mod_4fac, data = rude, estimator = "MLR", missing = "ML", 
                         sampling.weights = "wt_all", group = "country", 
                         group.equal = c("intercepts", "loadings"))
cfa_comp = lavaan::lavTestLRT(fit_configural, fit_weak, fit_strong) 
capture.output(cfa_comp, file = "cfa_mi_cnt.txt")


# by rural-urban 

mod_4fac = '
  iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
  rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
  redist =~ core_consc_12 + core_consc_13 
  cult =~ core_consc_14 + core_consc_15 + core_consc_16
'
fit_configural = list()
fit_weak = list()
fit_strong = list()
cfa_comp = list()
cnts = sort(unique(rude$country))

cfa_mi_rururb = foreach(i = 1:5, .packages = c("lavaan", "semTools")) %dopar% {
  fit_configural[[i]] = lavaan::cfa(mod_4fac, data = rude[rude$country==cnts[i],], 
                                    estimator = "MLR", missing = "ML", 
                                    sampling.weights = "wt_all", group = "rural")
  fit_weak[[i]] = lavaan::cfa(mod_4fac, data = rude[rude$country==cnts[i],], 
                              estimator = "MLR", missing = "ML", 
                              sampling.weights = "wt_all", group = "rural", 
                              group.equal = "loadings")
  fit_strong[[i]] = lavaan::cfa(mod_4fac, data = rude[rude$country==cnts[i],], 
                                estimator = "MLR", missing = "ML", 
                                sampling.weights = "wt_all", group = "rural", 
                                group.equal = c("intercepts", "loadings"))
  cfa_comp[[i]] = lavaan::lavTestLRT(
    fit_configural[[i]], fit_weak[[i]], fit_strong[[i]]) 
  capture.output(cfa_comp[[i]], file = paste0("cfa_mi_rur_urb_", cnts[i], ".txt"))
}

# by education

mod_4fac = '
  iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
  rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
  redist =~ core_consc_12 + core_consc_13 
  cult =~ core_consc_14 + core_consc_15 + core_consc_16
'
fit_configural = list()
fit_weak = list()
fit_strong = list()
cfa_comp = list()
cnts = sort(unique(rude$country))

cfa_mi_educ = foreach(i = 1:5, .packages = c("lavaan", "semTools")) %dopar% {
  fit_configural[[i]] = lavaan::cfa(mod_4fac, data = rude[rude$country==cnts[i],], 
                                    estimator = "MLR", missing = "ML", 
                                    sampling.weights = "wt_all", group = "educ_bach")
  fit_weak[[i]] = lavaan::cfa(mod_4fac, data = rude[rude$country==cnts[i],], 
                              estimator = "MLR", missing = "ML", 
                              sampling.weights = "wt_all", group = "educ_bach", 
                              group.equal = "loadings")
  fit_strong[[i]] = lavaan::cfa(mod_4fac, data = rude[rude$country==cnts[i],], 
                                estimator = "MLR", missing = "ML", 
                                sampling.weights = "wt_all", group = "educ_bach", 
                                group.equal = c("intercepts", "loadings"))
  cfa_comp[[i]] = lavaan::lavTestLRT(
    fit_configural[[i]], fit_weak[[i]], fit_strong[[i]]) 
  capture.output(cfa_comp[[i]], file = paste0("cfa_mi_educ_", cnts[i], ".txt"))
}



#### CFAs by country and rural-urban----


cnt_ru_split = split(rude, list(rude$country, rude$rural))
names_cnt_ru = c("che_urb", "deu_urb", "esp_urb", "fra_urb", "gbr_urb", "che_rur", "deu_rur", "esp_rur", "fra_rur", "gbr_rur")

mod_1fac = '
  consc =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5 + core_consc_6 + core_consc_7 
           + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
           + core_consc_12 + core_consc_13 + core_consc_14 + core_consc_15 + core_consc_16
'
mod_2fac = '
  iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
  resen =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
           + core_consc_12 + core_consc_13 + core_consc_14 + core_consc_15 + core_consc_16
'
mod_4fac = '
  iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
  rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
  redist =~ core_consc_12 + core_consc_13 
  cult =~ core_consc_14 + core_consc_15 + core_consc_16
'
mod_2hier_fac = '
  iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
  rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
  redist =~ core_consc_12 + core_consc_13 
  cult =~ core_consc_14 + core_consc_15 + core_consc_16
  resent =~ rep + redist + cult
'

mod_1f = list()
mod_2f = list()
mod_4f = list()
mod_4f_std = list()
mod_2hf = list()
cfa_comp = list()

cl = makeCluster(detectCores()) # Initialize parallel processing
registerDoParallel(cl)

cfa_cnt = foreach(i = 1:10, .packages = c("lavaan", "semTools")) %dopar% {
  mod_1f[[i]] = lavaan::cfa(mod_1fac, data = cnt_ru_split[[i]], estimator = "MLR", missing = "ML", 
                            sampling.weights = "wt_all")
  mod_2f[[i]] = lavaan::cfa(mod_2fac, data = cnt_ru_split[[i]], estimator = "MLR", missing = "ML", 
                            sampling.weights = "wt_all")
  mod_4f[[i]] = lavaan::cfa(mod_4fac, data = cnt_ru_split[[i]], estimator = "MLR", missing = "ML", 
                            sampling.weights = "wt_all")
  mod_4f_std[[i]] = lavaan::cfa(mod_4fac, data = cnt_ru_split[[i]], estimator = "MLR", missing = "ML", 
                                sampling.weights = "wt_all", std.lv = TRUE)
  mod_2hf[[i]] = lavaan::cfa(mod_2hier_fac, data = cnt_ru_split[[i]], estimator = "MLR", missing = "ML", 
                             sampling.weights = "wt_all")
  cfa_comp[[i]] = semTools::compareFit(mod_4f[[i]], mod_2hf[[i]], mod_2f[[i]], mod_1f[[i]]) 
  capture.output(summary(cfa_comp[[i]]), file = paste0("cfa_comparison_rururb_", names_cnt_ru[i], ".txt"))
  filename = paste0("cfa_4fac_std", names_cnt_ru[i], ".html")
  semTable::semTable(mod_4f_std[[i]], 
                     paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                   "latentcovariances", "fits"),
                     fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"),
                     type="html", print.results=FALSE, file=filename)
}




#### Plot consciousness by rural vs urban----


cnt_split = split(rude, rude$country)

mod_4fac = '
  pl_iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
  pl_res_rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
  pl_res_redist =~ core_consc_12 + core_consc_13 
  pl_res_cult =~ core_consc_14 + core_consc_15 + core_consc_16
'

mod_4f = list()
cons1 = list()
for(i in 1:5) {
  mod_4f[[i]] = cfa(mod_4fac, data = cnt_split[[i]], estimator = "MLR", missing = "ML", 
                    sampling.weights = "wt_all")
  cons1[[i]] = predict(mod_4f[[i]])
  cnt_split[[i]] = cbind(cnt_split[[i]], cons1[[i]])
}

dens_id_rur = list()
dens_id_urb = list()
dens_rep_rur = list()
dens_rep_urb = list()
dens_redist_rur = list()
dens_redist_urb = list()
dens_cult_rur = list()
dens_cult_urb = list()

for(i in 1:5) {
  wtr = cnt_split[[i]][cnt_split[[i]]$rural==1, "wt_all"] / length(cnt_split[[i]][cnt_split[[i]]$rural==1, "wt_all"])
  wtu = cnt_split[[i]][cnt_split[[i]]$rural==0, "wt_all"] / length(cnt_split[[i]][cnt_split[[i]]$rural==0, "wt_all"])
  dens_id_rur[[i]] = density(cnt_split[[i]][cnt_split[[i]]$rural==1, "pl_iden"], na.rm=TRUE, bw=0.15, weights=wtr)
  dens_rep_rur[[i]] = density(cnt_split[[i]][cnt_split[[i]]$rural==1, "pl_res_rep"], na.rm=TRUE, bw=0.15, weights=wtr)
  dens_redist_rur[[i]] = density(cnt_split[[i]][cnt_split[[i]]$rural==1, "pl_res_redist"], na.rm=TRUE, bw=0.15, weights=wtr)
  dens_cult_rur[[i]] = density(cnt_split[[i]][cnt_split[[i]]$rural==1, "pl_res_cult"], na.rm=TRUE, bw=0.15, weights=wtr)
  dens_id_urb[[i]] = density(cnt_split[[i]][cnt_split[[i]]$rural==0, "pl_iden"], na.rm=TRUE, bw=0.15, weights=wtu)
  dens_rep_urb[[i]] = density(cnt_split[[i]][cnt_split[[i]]$rural==0, "pl_res_rep"], na.rm=TRUE, bw=0.15, weights=wtu)
  dens_redist_urb[[i]] = density(cnt_split[[i]][cnt_split[[i]]$rural==0, "pl_res_redist"], na.rm=TRUE, bw=0.15, weights=wtu)
  dens_cult_urb[[i]] = density(cnt_split[[i]][cnt_split[[i]]$rural==0, "pl_res_cult"], na.rm=TRUE, bw=0.15, weights=wtu)
}

## plot identity

colurb = col2rgb("turquoise4") / 255
colrur = col2rgb("darkorange3") / 255
plot_cnts = c("CHE", "DEU", "ESP", "FRA", "GBR")

pdf("conscious_rur_urb.pdf", height=8, width=8)

layout(mat=cbind(1:5, 6:10, 11:15, 16:20), widths=c(0.27, 0.24, 0.24, 0.24), heights=c(0.22, 0.195, 0.195, 0.195, 0.195))

par(mar=c(1.5, 4, 2.5, 0.5), mgp=c(1.5, 0.4, 0), tcl=-0.2)

xr = c(dens_id_rur[[1]]$x, rev(dens_id_rur[[1]]$x))
yr = c(dens_id_rur[[1]]$y, rep(0, length(dens_id_rur[[1]]$y)))
xu = c(dens_id_urb[[1]]$x, rev(dens_id_urb[[1]]$x))
yu = c(dens_id_urb[[1]]$y, rep(0, length(dens_id_urb[[1]]$y)))
plot(dens_id_rur[[1]], main="", xlab="", ylab="Proportion", type="n", ylim=c(0, 1), 
     xlim=c(-2.2, 2.2), cex.axis=1.1, cex.lab=1.1)
grid()
legend("topleft", fill=c(rgb(0.8, 0.4, 0, 0.6), rgb(0, 0.3, 0.3, 0.6)), 
       legend=c("Urban", "Rural"), bty="n", cex=1.2)
polygon(x=xr, y=yr, col=rgb(0, 0.3, 0.3, 0.6), border=FALSE)
polygon(x=xu, y=yu, col=rgb(0.8, 0.4, 0, 0.6), border=FALSE)
mtext(side=2, line=2.4, text=plot_cnts[1], cex=0.9)
mtext(side=3, line=0.5, text="Identity", cex=0.9)

par(mar=c(1.5, 4, 1, 0.5), mgp=c(1.5, 0.4, 0), tcl=-0.2)
for(i in 2:5) {
  xr = c(dens_id_rur[[i]]$x, rev(dens_id_rur[[i]]$x))
  yr = c(dens_id_rur[[i]]$y, rep(0, length(dens_id_rur[[i]]$y)))
  xu = c(dens_id_urb[[i]]$x, rev(dens_id_urb[[i]]$x))
  yu = c(dens_id_urb[[i]]$y, rep(0, length(dens_id_urb[[i]]$y)))
  plot(dens_id_rur[[i]], main="", xlab="", ylab="Proportion", type="n", ylim=c(0, 1), 
       xlim=c(-2.2, 2.2), cex.axis=1.1, cex.lab=1.1)
  grid()
  polygon(x=xr, y=yr, col=rgb(0, 0.3, 0.3, 0.6), border=FALSE)
  polygon(x=xu, y=yu, col=rgb(0.8, 0.4, 0, 0.6), border=FALSE)
  mtext(side=2, line=2.4, text=plot_cnts[i], cex=0.9)
}

## plot representation

par(mar=c(1.5, 2, 2.5, 0.5), mgp=c(1.5, 0.4, 0), tcl=-0.2)

xr = c(dens_rep_rur[[1]]$x, rev(dens_rep_rur[[1]]$x))
yr = c(dens_rep_rur[[1]]$y, rep(0, length(dens_rep_rur[[1]]$y)))
xu = c(dens_rep_urb[[1]]$x, rev(dens_rep_urb[[1]]$x))
yu = c(dens_rep_urb[[1]]$y, rep(0, length(dens_rep_urb[[1]]$y)))
plot(dens_rep_rur[[1]], main="", xlab="", ylab="", type="n", ylim=c(0, 1), 
     xlim=c(-2.2, 2.2), cex.axis=1.1)
grid()
polygon(x=xr, y=yr, col=rgb(0, 0.3, 0.3, 0.6), border=FALSE)
polygon(x=xu, y=yu, col=rgb(0.8, 0.4, 0, 0.6), border=FALSE)
mtext(side=3, line=0.5, text="Power", cex=0.9)

par(mar=c(1.5, 2, 1, 0.5), mgp=c(1.5, 0.4, 0), tcl=-0.2)
for(i in 2:5) {
  xr = c(dens_rep_rur[[i]]$x, rev(dens_rep_rur[[i]]$x))
  yr = c(dens_rep_rur[[i]]$y, rep(0, length(dens_rep_rur[[i]]$y)))
  xu = c(dens_rep_urb[[i]]$x, rev(dens_rep_urb[[i]]$x))
  yu = c(dens_rep_urb[[i]]$y, rep(0, length(dens_rep_urb[[i]]$y)))
  plot(dens_rep_rur[[i]], main="", xlab="", ylab="", type="n", ylim=c(0, 1), xlim=c(-2.2, 2.2),
       cex.axis=1.1)
  grid()
  polygon(x=xr, y=yr, col=rgb(0, 0.3, 0.3, 0.6), border=FALSE)
  polygon(x=xu, y=yu, col=rgb(0.8, 0.4, 0, 0.6), border=FALSE)
}

## plot redistribution

par(mar=c(1.5, 2, 2.5, 0.5), mgp=c(1.5, 0.4, 0), tcl=-0.2)

xr = c(dens_redist_rur[[1]]$x, rev(dens_redist_rur[[1]]$x))
yr = c(dens_redist_rur[[1]]$y, rep(0, length(dens_redist_rur[[1]]$y)))
xu = c(dens_redist_urb[[1]]$x, rev(dens_redist_urb[[1]]$x))
yu = c(dens_redist_urb[[1]]$y, rep(0, length(dens_redist_urb[[1]]$y)))
plot(dens_redist_rur[[1]], main="", xlab="", ylab="", type="n", ylim=c(0, 1), xlim=c(-2.2, 2.2), 
     cex.axis=1.1)
grid()
polygon(x=xr, y=yr, col=rgb(0, 0.3, 0.3, 0.6), border=FALSE)
polygon(x=xu, y=yu, col=rgb(0.8, 0.4, 0, 0.6), border=FALSE)
mtext(side=3, line=0.5, text="Resources", cex=0.9)

par(mar=c(1.5, 2, 1, 0.5), mgp=c(1.5, 0.4, 0), tcl=-0.2)
for(i in 2:5) {
  xr = c(dens_redist_rur[[i]]$x, rev(dens_redist_rur[[i]]$x))
  yr = c(dens_redist_rur[[i]]$y, rep(0, length(dens_redist_rur[[i]]$y)))
  xu = c(dens_redist_urb[[i]]$x, rev(dens_redist_urb[[i]]$x))
  yu = c(dens_redist_urb[[i]]$y, rep(0, length(dens_redist_urb[[i]]$y)))
  plot(dens_redist_rur[[i]], main="", xlab="", ylab="", type="n", ylim=c(0, 1), 
       xlim=c(-2.2, 2.2), cex.axis=1.1)
  grid()
  polygon(x=xr, y=yr, col=rgb(0, 0.3, 0.3, 0.6), border=FALSE)
  polygon(x=xu, y=yu, col=rgb(0.8, 0.4, 0, 0.6), border=FALSE)
}

## plot culture

par(mar=c(1.5, 2, 2.5, 0.5), mgp=c(1.5, 0.4, 0), tcl=-0.2)

xr = c(dens_cult_rur[[1]]$x, rev(dens_cult_rur[[1]]$x))
yr = c(dens_cult_rur[[1]]$y, rep(0, length(dens_cult_rur[[1]]$y)))
xu = c(dens_cult_urb[[1]]$x, rev(dens_cult_urb[[1]]$x))
yu = c(dens_cult_urb[[1]]$y, rep(0, length(dens_cult_urb[[1]]$y)))
plot(dens_cult_rur[[1]], main="", xlab="", ylab="", type="n", ylim=c(0, 1), xlim=c(-2.2, 2.2),
     cex.axis=1.1)
grid()
polygon(x=xr, y=yr, col=rgb(0, 0.3, 0.3, 0.6), border=FALSE)
polygon(x=xu, y=yu, col=rgb(0.8, 0.4, 0, 0.6), border=FALSE)
mtext(side=3, line=0.5, text="Culture", cex=0.9)

par(mar=c(1.5, 2, 1, 0.5), mgp=c(1.5, 0.4, 0), tcl=-0.2)
for(i in 2:5) {
  xr = c(dens_cult_rur[[i]]$x, rev(dens_cult_rur[[i]]$x))
  yr = c(dens_cult_rur[[i]]$y, rep(0, length(dens_cult_rur[[i]]$y)))
  xu = c(dens_cult_urb[[i]]$x, rev(dens_cult_urb[[i]]$x))
  yu = c(dens_cult_urb[[i]]$y, rep(0, length(dens_cult_urb[[i]]$y)))
  plot(dens_cult_rur[[i]], main="", xlab="", ylab="", type="n", ylim=c(0, 1), xlim=c(-2.2, 2.2), 
       cex.axis=1.1)
  grid()
  polygon(x=xr, y=yr, col=rgb(0, 0.3, 0.3, 0.6), border=FALSE)
  polygon(x=xu, y=yu, col=rgb(0.8, 0.4, 0, 0.6), border=FALSE)
}

dev.off()

# averages by country, dimension, rural-urban

for (i in 1:5) {
  print(
    by(cnt_split[[i]][, "pl_iden"], cnt_split[[i]][, "rural"], mean, na.rm=T, simplify=T)[1] -
      by(cnt_split[[i]][, "pl_iden"], cnt_split[[i]][, "rural"], mean, na.rm=T, simplify=T)[2]
    )
}

for (i in 1:5) {
  print(
    by(cnt_split[[i]][, "pl_res_rep"], cnt_split[[i]][, "rural"], mean, na.rm=T, simplify=T)[1] -
      by(cnt_split[[i]][, "pl_res_rep"], cnt_split[[i]][, "rural"], mean, na.rm=T, simplify=T)[2]
  )
}

for (i in 1:5) {
  print(
    by(cnt_split[[i]][, "pl_res_redist"], cnt_split[[i]][, "rural"], mean, na.rm=T, simplify=T)[1] -
      by(cnt_split[[i]][, "pl_res_redist"], cnt_split[[i]][, "rural"], mean, na.rm=T, simplify=T)[2]
  )
}

for (i in 1:5) {
  print(
    by(cnt_split[[i]][, "pl_res_cult"], cnt_split[[i]][, "rural"], mean, na.rm=T, simplify=T)[1] -
      by(cnt_split[[i]][, "pl_res_cult"], cnt_split[[i]][, "rural"], mean, na.rm=T, simplify=T)[2]
  )
}



#### SEMs by country----


## FIML

cnt_split = split(rude, rude$country)

mod_4f_sem_1 = '
 iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
 rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
 redist =~ core_consc_12 + core_consc_13 
 cult =~ core_consc_14 + core_consc_15 + core_consc_16
 iden ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
 rep ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
 redist ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
 cult ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
'

sem_cnt = foreach(i = 1:5)  %dopar% {
  sem_1_out = lavaan::sem(mod_4f_sem_1, data = cnt_split[[i]], estimator = "MLR", missing = "ML", 
                          sampling.weights = "wt_all")
  filename = paste0("sem_1_4fac_", i, ".html")
  semTable::semTable(sem_1_out, paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                              "latentcovariances", "fits"),
           fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"),
           type="html", print.results=FALSE, file=filename)
}
  

## FIML, standardized

sem_1_std = list()
sem_cnt = foreach(i = 1:5)  %dopar% {
  sem_1_std[[i]] = lavaan::sem(mod_4f_sem_1, data=cnt_split[[i]], estimator="MLR", missing="ML", 
                               sampling.weights="wt_all", std.lv=TRUE)
  filename = paste0("sem_1_4fac_std_", i)
  semTable::semTable(sem_1_std[[i]], paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                                   "latentcovariances", "fits"),
           fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"), type="html", 
           print.results=FALSE, file=filename)
  semTable::semTable(sem_1_std[[i]], paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                                   "latentcovariances", "fits"),
           fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"), type="latex",
           print.results=FALSE, file=filename)
  semTable::semTable(sem_1_std[[i]], paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                                   "latentcovariances", "fits"),
           fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"), type="csv",
           print.results=FALSE, file=filename)
}


## ordered

rude_ord = rude
rude_ord[, names(cons)] = sapply(rude_ord[, names(cons)], as.ordered)
cnt_split = split(rude_ord, rude_ord$country)

sem_cnt = foreach(i = 1:5)  %dopar% {
  sem_ord_out = lavaan::sem(mod_4f_sem_1, data = cnt_split[[i]], estimator = "WLSMV", ordered = TRUE, 
                            sampling.weights = "wt_all")
  filename = paste0("sem_ord_4fac_", i, ".html")
  semTable::semTable(sem_ord_out, paramSets = c("slopes", "loadings", "latentvariances", 
                                                "latentcovariances", "fits"),
           fits=c("chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"),
           type="html", print.results=FALSE, file=filename)
}


## FIML, with country dummies

cnt_split = split(rude, rude$country)
names_cnt = sort(unique(rude$country))

mod_4f_sem_1 = '
 iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
 rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
 redist =~ core_consc_12 + core_consc_13 
 cult =~ core_consc_14 + core_consc_15 + core_consc_16
 iden ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
 rep ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
 redist ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
 cult ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
'

cnt_dummies = list(
  che = grep("^region1(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE),
  deu = grep("^region2(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE),
  esp = grep("^region3(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE) %>% 
    setdiff(c("region320", "region321")),
  fra = grep("^region4(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE) %>% 
    setdiff("region411"),
  gbr = grep("^region5(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE)
)

sem_cnt = foreach(i = 1:5)  %dopar% {
  reg_dummies = cnt_dummies[[i]]
  
  mod_4f_sem_1 = paste0('
   iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
   rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
   redist =~ core_consc_12 + core_consc_13 
   cult =~ core_consc_14 + core_consc_15 + core_consc_16
   iden ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
   rep ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
   redist ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
   cult ~ rural + female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
  ')
  
  sem_reg_out = lavaan::sem(mod_4f_sem_1, data = cnt_split[[i]], estimator = "MLR", missing = "ML", 
                            sampling.weights = "wt_all", std.lv=TRUE)
  filename = paste0("sem_4fac_std_reg_", names_cnt[i], ".html")
  semTable::semTable(sem_reg_out, paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                                "latentcovariances", "fits"),
                     fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"),
                     type="html", print.results=FALSE, file=filename)
}



#### SEMs by country and rural-urban----


## FIML

cnt_ru_split = split(rude, list(rude$country, rude$rural))
names_cnt_ru = c("che_urb", "deu_urb", "esp_urb", "fra_urb", "gbr_urb", "che_rur", "deu_rur", "esp_rur", 
                 "fra_rur", "gbr_rur")

mod_4f_sem_1 = paste0('
 iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
 rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
 redist =~ core_consc_12 + core_consc_13 
 cult =~ core_consc_14 + core_consc_15 + core_consc_16
 iden ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
 rep ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
 redist ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
 cult ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright
')

sem_cnt = foreach(i = 1:10)  %dopar% {
  sem_ru_out = lavaan::sem(mod_4f_sem_1, data = cnt_ru_split[[i]], estimator = "MLR", missing = "ML", 
                           sampling.weights = "wt_all")
  filename = paste0("sem_rurb_4fac_", names_cnt_ru[i], ".html")
  semTable::semTable(sem_ru_out, paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                               "latentcovariances", "fits"),
           fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"),
           type="html", print.results=FALSE, file=filename)
}


## FIML, standardized

sem_ru_std = list()
sem_cnt = foreach(i = 1:10)  %dopar% {
  sem_ru_std[[i]] = lavaan::sem(mod_4f_sem_1, data=cnt_ru_split[[i]], estimator="MLR", missing="ML", 
                                sampling.weights="wt_all", std.lv=TRUE)
  filename = paste0("sem_rurb_4fac_std_", names_cnt_ru[i])
  semTable::semTable(sem_ru_std[[i]], paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                                    "latentcovariances", "fits"),
           fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"), type="html", 
           print.results=FALSE, file=filename)
  semTable::semTable(sem_ru_std[[i]], paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                                    "latentcovariances", "fits"),
           fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"), type="latex",
           print.results=FALSE, file=filename)
  semTable::semTable(sem_ru_std[[i]], paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                                    "latentcovariances", "fits"),
           fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"), type="csv",
           print.results=FALSE, file=filename)
}


## ordered

rude_ord = rude
rude_ord[, names(cons)] = sapply(rude_ord[, names(cons)], as.ordered)
cnt_ru_split = split(rude_ord, list(rude_ord$country, rude_ord$rural))

sem_cnt = foreach(i = 1:10)  %dopar% {
  sem_ru_ord_out = lavaan::sem(mod_4f_sem_1, data = cnt_ru_split[[i]], estimator = "WLSMV", ordered = TRUE, 
                               sampling.weights = "wt_all")
  filename = paste0("sem_ord_rurb_4fac_v2_", names_cnt_ru[i], ".html")
  semTable::semTable(sem_ru_ord_out, paramSets = 
                       c("slopes", "loadings", "latentvariances", "latentcovariances", "fits"),
           fits=c("chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"),
           type="html", print.results=FALSE, file=filename)
}


## FIML, with country dummies

cnt_ru_split = split(rude, list(rude$country, rude$rural))
names_cnt_ru = c("che_urb", "deu_urb", "esp_urb", "fra_urb", "gbr_urb", "che_rur", "deu_rur", "esp_rur", 
                 "fra_rur", "gbr_rur")

cnt_ru_dummies = list(
  che_urb = grep("^region1(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE),
  deu_urb = grep("^region2(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE),
  esp_urb = grep("^region3(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE) %>% 
    setdiff(c("region320", "region321")),
  fra_urb = grep("^region4(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE) %>% 
    setdiff("region411"),
  gbr_urb = grep("^region5(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE),
  che_rur = grep("^region1(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE),
  deu_rur = grep("^region2(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE),
  esp_rur = grep("^region3(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE) %>% 
    setdiff(c("region320", "region321")),
  fra_rur = grep("^region4(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE) %>% 
    setdiff("region411"),
  gbr_rur = grep("^region5(0[2-9]|[1-9][0-9])", colnames(region_dummies), value = TRUE)
)

sem_cnt = foreach(i = 1:10)  %dopar% {
  reg_dummies = cnt_ru_dummies[[i]]
  
  mod_4f_sem_1 = paste0('
   iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
   rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
   redist =~ core_consc_12 + core_consc_13 
   cult =~ core_consc_14 + core_consc_15 + core_consc_16
   iden ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
   rep ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
   redist ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
   cult ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
  ')

  sem_reg_out = lavaan::sem(mod_4f_sem_1, data = cnt_ru_split[[i]], estimator = "MLR", missing = "ML", 
                            sampling.weights = "wt_all", std.lv=TRUE)
  filename = paste0("sem_rurb_4fac_reg_", names_cnt_ru[i], ".html")
  semTable::semTable(sem_reg_out, paramSets = c("intercepts", "slopes", "loadings", "latentvariances", 
                                                "latentcovariances", "fits"),
                     fits=c("ntotal", "chisq", "cfi", "rmsea", "srmr"), columns=c("estse", "p"),
                     type="html", print.results=FALSE, file=filename)
}



## Coef plots for country-rural-urban samples, FIML, standardized
## run SEMs again and extract key parameters

cnt_ru_split = split(rude, list(rude$country, rude$rural))
names_cnt_ru = c("che_urb", "deu_urb", "esp_urb", "fra_urb", "gbr_urb", "che_rur", "deu_rur", "esp_rur", 
                 "fra_rur", "gbr_rur")

sem_std_out = list()
iv_list = c("female", "educ_bach", "income_hi", "income_med", "age3549", "age5064", "age65", "leftright")
for(i in 1:10) {
  
  reg_dummies = cnt_ru_dummies[[i]]
  
  mod_4f_sem_1 = paste0('
   iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
   rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
   redist =~ core_consc_12 + core_consc_13 
   cult =~ core_consc_14 + core_consc_15 + core_consc_16
   iden ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
   rep ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
   redist ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
   cult ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright + ', paste(reg_dummies, collapse = " + "), '
  ')
  
  sem_std_out[[i]] = lavaan::sem(mod_4f_sem_1, data=cnt_ru_split[[i]], estimator="MLR", missing="ML", 
                            sampling.weight="wt_all", std.lv=TRUE)
  pars_sem = parameterEstimates(sem_std_out[[i]])
  assign(paste0("pars_iden_reg_", names_cnt_ru[i]), pars_sem[pars_sem$lhs=="iden" & pars_sem$rhs %in% iv_list, ])
  assign(paste0("pars_rep_reg_", names_cnt_ru[i]), pars_sem[pars_sem$lhs=="rep" & pars_sem$rhs %in% iv_list, ])
  assign(paste0("pars_redist_reg_", names_cnt_ru[i]), pars_sem[pars_sem$lhs=="redist" & pars_sem$rhs %in% iv_list, ])
  assign(paste0("pars_cult_reg_", names_cnt_ru[i]), pars_sem[pars_sem$lhs=="cult" & pars_sem$rhs %in% iv_list, ])
}

colurb = rgb(0.6, 0.25, 0, 1)
colrur = rgb(0, 0.3, 0.3, 1)
x_lim = c(-0.8, 1.4)
x_tick = seq(from=-1, to=1.5, by = 0.5)
x_labs = c(1, 0.5, 0, 0.5, 1, "")
iv_names = c("female", "educ: degree", "income: high", "income: med", "age: 35-49", "age: 50-64", "age: 65+", "left v right")
dv_list = c("iden", "rep", "redist", "cult")
cnt_list = c("che", "deu", "esp", "fra", "gbr")
var_names = c("\nIdentity", "Power\nresentment", "Resource\nresentment", "Cultural\nresentment")
cnt_names = c("CHE", "DEU", "ESP", "FRA", "GBR")

pdf("sem_plots_reg.pdf", height=8, width=6.5)

layout_mat = matrix(1:20, nrow=5, ncol=4, byrow=TRUE) 
layout(layout_mat, widths=c(0.33, 0.215, 0.215, 0.215), heights=c(0.22, 0.19, 0.19, 0.19, 0.19) )

# first country / row

for(i in 1:length(dv_list)) { 
  par_vec_urb = get(paste0("pars_", dv_list[i], "_reg_che_urb"))
  par_vec_rur = get(paste0("pars_", dv_list[i], "_reg_che_rur"))
  
  if(i==1) { 
    par(mar=c(1.5, 6.5, 2.7, 0.5), tcl=-0.2) 
  } else { par(mar=c(1.5, 0.5, 2.7, 0.5), tcl=-0.2) 
    }
  plot(x=par_vec_urb$est, y=8:1, type="n", axes=FALSE, xlim=x_lim, ylim=c(0.5, 8.5), 
       xlab="", ylab="")
  axis(side=1, at=x_tick, labels=x_labs, cex.axis=0.9, mgp=c(1, 0.2, 0), lwd=0.75, gap.axis=0.1)
  if(i==1) {  
    axis(side=2, at=8:1, labels=iv_names, cex.axis=0.95, mgp=c(1, 0.4, 0), las=1, lwd=0.85)
  } else { 
    axis(side=2, at=8:1, labels=FALSE, cex.axis=0.95, mgp=c(1, 0.4, 0), las=1, lwd=0.85)
      }
  abline(h=1:8, lty=3, lwd=0.6, col=rgb(0.3, 0.3, 0.3, 0.5))
  abline(v=0, lty=1, lwd=0.6, col=rgb(0.3, 0.3, 0.3, 0.5))
  mtext(text=var_names[i], side=3, line=0.3, at=median(x_tick), cex=0.8)
  if(i==1) {  
    mtext(text=cnt_names[1], side=2, line=1.5, at=9.5, las=1, cex=0.8)
  } 
  # urban data
  segments(x0=par_vec_urb$ci.lower, x1=par_vec_urb$ci.upper, y0=(8:1)+0.15, lwd=1, col=colurb)
  points(x=par_vec_urb$est, y=(8:1)+0.15, pch=16, col=colurb, cex=1)
  # rural data
  segments(x0=par_vec_rur$ci.lower, x1=par_vec_rur$ci.upper, y0=(8:1)-0.15, lwd=1, col=colrur)
  points(x=par_vec_rur$est, y=(8:1)-0.15, bg="white", pch=21, col=colrur, cex=0.9)
  if (i==1){
    legend("topright", legend=c("urban", "rural"), col=c(colurb, colrur), 
           text.col=c(colurb, colrur), pch=c(16, 21), box.lty=0, cex=0.9, 
           pt.cex=1, x.intersp=0.5, y.intersp=0.75)
  }
  box()
}

# countries / rows 2-5

for(j in 2:length(cnt_list)) { 
  
  for(i in 1:length(dv_list)) { 
    par_vec_urb = get(paste0("pars_", dv_list[i], "_reg_", cnt_list[j], "_urb"))
    par_vec_rur = get(paste0("pars_", dv_list[i], "_reg_", cnt_list[j], "_rur"))
    
    if(i==1) { 
      par(mar=c(1.5, 6.5, 0.5, 0.5), tcl=-0.2) 
    } else { par(mar=c(1.5, 0.5, 0.5, 0.5), tcl=-0.2) 
    }
    plot(x=par_vec_urb$est, y=8:1, type="n", axes=FALSE, xlim=x_lim, ylim=c(0.5, 8.5), 
         xlab="", ylab="")
    axis(side=1, at=x_tick, labels=x_labs, cex.axis=0.9, mgp=c(1, 0.2, 0), lwd=0.75, gap.axis=0.1)
    if(i==1) {  
      axis(side=2, at=8:1, labels=iv_names, cex.axis=0.95, mgp=c(1, 0.4, 0), las=1, lwd=0.85)
    } else { 
      axis(side=2, at=8:1, labels=FALSE, cex.axis=0.95, mgp=c(1, 0.4, 0), las=1, lwd=0.85)
    }
    abline(h=1:8, lty=3, lwd=0.6, col=rgb(0.3, 0.3, 0.3, 0.5))
    abline(v=0, lty=1, lwd=0.6, col=rgb(0.3, 0.3, 0.3, 0.5))
    if(i==1) {  
      mtext(text=cnt_names[j], side=2, line=1.5, at=9.5, las=1, cex=0.8)
    } 
    # urban data
    segments(x0=par_vec_urb$ci.lower, x1=par_vec_urb$ci.upper, y0=(8:1)+0.15, lwd=1, col=colurb)
    points(x=par_vec_urb$est, y=(8:1)+0.15, pch=16, col=colurb, cex=1)
    # rural data
    segments(x0=par_vec_rur$ci.lower, x1=par_vec_rur$ci.upper, y0=(8:1)-0.15, lwd=1, col=colrur)
    points(x=par_vec_rur$est, y=(8:1)-0.15, pch=21, bg="white", col=colrur, cex=0.9)
    if (i==1){
      legend("topright", legend=c("urban", "rural"), col=c(colurb, colrur), 
             text.col=c(colurb, colrur), pch=c(16, 21), box.lty=0, cex=0.9, 
             pt.cex=1, x.intersp=0.5, y.intersp=0.75)
    }
    box()
  }
}

dev.off()



#### SEMs by country and full rural-urban classification----


cnt_ru6_split = split(rude, list(rude$country, rude$core_filt))
names_cnt_ru6 = c("che_1", "deu_1", "esp_1", "fra_1", "gbr_1", 
                  "che_2", "deu_2", "esp_2", "fra_2", "gbr_2",
                  "che_3", "deu_3", "esp_3", "fra_3", "gbr_3",
                  "che_4", "deu_4", "esp_4", "fra_4", "gbr_4",
                  "che_5", "deu_5", "esp_5", "fra_5", "gbr_5",
                  "che_6", "deu_6", "esp_6", "fra_6", "gbr_6")

# run sems and extract key parameters

sem_std_out = list()
iv_list = c("female", "educ_bach", "income_hi", "income_med", "age3549", "age5064", "age65", "leftright")
for(i in 1:30) {
  
  mod_4f_sem = paste0('
   iden =~ core_consc_1 + core_consc_2 + core_consc_3 + core_consc_4 + core_consc_5
   rep =~ core_consc_6 + core_consc_7 + core_consc_8 + core_consc_9 + core_consc_10 + core_consc_11 
   redist =~ core_consc_12 + core_consc_13 
   cult =~ core_consc_14 + core_consc_15 + core_consc_16
   iden ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright 
   rep ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright  
   redist ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright  
   cult ~ female + educ_bach + income_na + income_hi + income_med + age3549 + age5064 + age65 + leftright 
  ')
  
  sem_std_out[[i]] = lavaan::sem(mod_4f_sem, data=cnt_ru6_split[[i]], 
                                 estimator="MLR", missing="ML", 
                                 sampling.weight="wt_all", std.lv=TRUE)
  pars_sem = parameterEstimates(sem_std_out[[i]])
  assign(paste0("pars_iden_ru6_", names_cnt_ru6[i]), pars_sem[pars_sem$lhs=="iden" & pars_sem$rhs %in% iv_list, ])
  assign(paste0("pars_rep_ru6_", names_cnt_ru6[i]), pars_sem[pars_sem$lhs=="rep" & pars_sem$rhs %in% iv_list, ])
  assign(paste0("pars_redist_ru6_", names_cnt_ru6[i]), pars_sem[pars_sem$lhs=="redist" & pars_sem$rhs %in% iv_list, ])
  assign(paste0("pars_cult_ru6_", names_cnt_ru6[i]), pars_sem[pars_sem$lhs=="cult" & pars_sem$rhs %in% iv_list, ])
}

x_lim = c(-1.2, 1.8)
x_tick = seq(from=-1, to=2, by = 0.5)
x_labs = c(1, 0.5, 0, 0.5, 1, 1.5, "")
y_sep = c(0.30, 0.18, 0.06, -0.06, -0.18, -0.30)
iv_names = c("female", "educ: degree", "income: high", "income: med", "age: 35-49", "age: 50-64", "age: 65+", "left v right")
dv_list = c("iden", "rep", "redist", "cult")
cnt_list = c("che", "deu", "esp", "fra", "gbr")
var_names = c("\nIdentity", "Power\nresentment", "Resource\nresentment", "Cultural\nresentment")
cnt_names = c("CHE", "DEU", "ESP", "FRA", "GBR")

pdf("sem_plots_ru6.pdf", height=8, width=6.5)

layout_mat = matrix(1:20, nrow=5, ncol=4, byrow=TRUE) 
layout(layout_mat, widths=c(0.34, 0.215, 0.215, 0.215), heights=c(0.22, 0.19, 0.19, 0.19, 0.19) )
pal6 = viridis(6)

# first country / row

for(i in 1:length(dv_list)) { 
  for(j in 1:6) {
    assign(paste0("par_vec_", j), get(paste0("pars_", dv_list[i], "_ru6_che_", j)))
  }
  
  if(i==1) { 
    par(mar=c(1.5, 6.5, 2.7, 0.5), tcl=-0.2) 
  } else { par(mar=c(1.5, 0.5, 2.7, 0.5), tcl=-0.2) 
  }
  plot(x=par_vec_1$est, y=8:1, type="n", axes=FALSE, xlim=x_lim, ylim=c(0.5, 8.5), 
       xlab="", ylab="")
  axis(side=1, at=x_tick, labels=x_labs, cex.axis=0.8, mgp=c(1, 0.2, 0), lwd=0.75, gap.axis=0.1)
  if(i==1) {  
    axis(side=2, at=8:1, labels=iv_names, cex.axis=0.8, mgp=c(1, 0.4, 0), las=1, lwd=0.85)
  } else { 
    axis(side=2, at=8:1, labels=FALSE, cex.axis=0.8, mgp=c(1, 0.4, 0), las=1, lwd=0.85)
  }
  abline(h=1:8, lty=3, lwd=0.6, col=rgb(0.3, 0.3, 0.3, 0.5))
  abline(v=0, lty=1, lwd=0.6, col=rgb(0.3, 0.3, 0.3, 0.5))
  mtext(text=var_names[i], side=3, line=0.3, at=median(x_tick), cex=0.7)
  if(i==1) {  
    mtext(text=cnt_names[1], side=2, line=1.5, at=9.5, las=1, cex=0.7)
  } 
  for(j in 1:6) {
    par_vec = get(paste0("par_vec_", j))
    segments(x0=par_vec$ci.lower, x1=par_vec$ci.upper, y0=(8:1)+y_sep[j], 
             lwd=1, col=pal6[j])
    points(x=par_vec$est, y=(8:1)+y_sep[j], pch=16, col=pal6[j], cex=0.75)
  }
  box()
}

# countries / rows 2-5

for(k in 2:length(cnt_list)) { 
  
  for(i in 1:length(dv_list)) { 
    for(j in 1:6) {
      assign(paste0("par_vec_", j), 
             get(paste0("pars_", dv_list[i], "_ru6_", cnt_list[k], "_", j)))
    }
    
    if(i==1) { 
      par(mar=c(1.5, 6.5, 0.5, 0.5), tcl=-0.2) 
    } else { par(mar=c(1.5, 0.5, 0.5, 0.5), tcl=-0.2) 
    }
    plot(x=par_vec_1$est, y=8:1, type="n", axes=FALSE, xlim=x_lim, ylim=c(0.5, 8.5), 
         xlab="", ylab="")
    axis(side=1, at=x_tick, labels=x_labs, cex.axis=0.8, mgp=c(1, 0.2, 0), lwd=0.75, gap.axis=0.1)
    if(i==1) {  
      axis(side=2, at=8:1, labels=iv_names, cex.axis=0.8, mgp=c(1, 0.4, 0), las=1, lwd=0.85)
    } else { 
      axis(side=2, at=8:1, labels=FALSE, cex.axis=0.8, mgp=c(1, 0.4, 0), las=1, lwd=0.85)
    }
    abline(h=1:8, lty=3, lwd=0.6, col=rgb(0.3, 0.3, 0.3, 0.5))
    abline(v=0, lty=1, lwd=0.6, col=rgb(0.3, 0.3, 0.3, 0.5))
    if(i==1) {  
      mtext(text=cnt_names[k], side=2, line=1.5, at=9.5, las=1, cex=0.7)
    } 
    for(j in 1:6) {
      par_vec = get(paste0("par_vec_", j))
      segments(x0=par_vec$ci.lower, x1=par_vec$ci.upper, y0=(8:1)+y_sep[j], 
               lwd=1, col=pal6[j])
      points(x=par_vec$est, y=(8:1)+y_sep[j], pch=16, col=pal6[j], cex=0.7)
    }
    box()
  }
}

dev.off()



# Stop parallel processing
stopCluster(cl)

